@@ -1,6 +1,7 @@
 package formatters_test
 
 import (
+	"strings"
 	"testing"
 
 	"github.com/oasdiff/oasdiff/checker"
@@ -31,6 +32,19 @@ func TestYamlFormatter_RenderChangelog(t *testing.T) {
 	require.Equal(t, "- id: change_id\n  text: This is a breaking change.\n  level: 3\n  section: components\n", string(out))
 }
 
+func TestYamlFormatter_RenderChangelogWithWrapInObject(t *testing.T) {
+	testChanges := checker.Changes{
+		checker.ComponentChange{
+			Id:    "change_id",
+			Level: checker.ERR,
+		},
+	}
+
+	out, err := yamlFormatter.RenderChangelog(testChanges, formatters.RenderOpts{WrapInObject: true}, nil)
+	require.NoError(t, err)
+	require.True(t, strings.HasPrefix(string(out), "changes:"))
+}
+
 func TestYamlFormatter_RenderChecks(t *testing.T) {
 	checks := formatters.Checks{
 		{
