@@ -5,8 +5,8 @@ package load_test
 import (
 	"testing"
 
+	"github.com/oasdiff/oasdiff/load"
 	"github.com/stretchr/testify/require"
-	"github.com/tufin/oasdiff/load"
 )
 
 func TestLoadInfo_FileWindows(t *testing.T) {
