@@ -6,8 +6,8 @@ go mod download && go mod tidy && go mod verify
 go vet ./...
 
 # update breaking-changes examples doc
-./scripts/doc_breaking_changes.sh > BREAKING-CHANGES-EXAMPLES.md
+./scripts/doc_breaking_changes.sh > docs/BREAKING-CHANGES-EXAMPLES.md
 
 go fmt ./...
 
-git add "BREAKING-CHANGES-EXAMPLES.md"
\ No newline at end of file
+git add "docs/BREAKING-CHANGES-EXAMPLES.md"
\ No newline at end of file
